@@ -22,7 +22,7 @@
 #' @importFrom gifti readgii is.gifti
 #'
 #' @family reading
-#' @family surfing
+#' @family surface-related
 #' @export
 #' 
 read_surf <- function(surf, expected_hemisphere=NULL, resamp_res=NULL) {
@@ -46,6 +46,10 @@ read_surf <- function(surf, expected_hemisphere=NULL, resamp_res=NULL) {
     } else {
       surf <- readgii(surf) 
     }
+  } else {
+    if (length(surf)==1 && is.character(surf)) {
+      stop("`surf` is a length-one character vector, but is not an existing file path.")
+    }
   }
 
   # GIFTI --> list of vertices and faces.
@@ -55,7 +59,7 @@ read_surf <- function(surf, expected_hemisphere=NULL, resamp_res=NULL) {
       ps_idx <- which(names(surf$data) == "pointset")[1]
       ps_meta <- surf$data_meta[[ps_idx]]
       hemisphere <- ps_meta[which(ps_meta[,1] == "AnatomicalStructurePrimary"),2]
-      if (!(hemisphere %in% c("CortexLeft", "CortexRight"))) {
+      if ((length(hemisphere)!=1) || (!(hemisphere %in% c("CortexLeft", "CortexRight")))) {
         stop(paste0(
           "The hemisphere metadata entry (AnatomicalStructurePrimary) was not ",
           "CortexLeft or CortexRight. Instead, it was ", hemisphere, 
@@ -69,7 +73,7 @@ read_surf <- function(surf, expected_hemisphere=NULL, resamp_res=NULL) {
     } else {
       hemisphere <- switch(hemisphere, CortexLeft="left", CortexRight="right")
     }
-    if (!is.null(expected_hemisphere)) {
+    if ((!is.null(hemisphere)) && (!is.null(expected_hemisphere))) {
       if (hemisphere != expected_hemisphere) {
         stop(paste(
           "The expected hemisphere was", expected_hemisphere, 
